@@ -15,6 +15,7 @@ except ImportError:
     import httplib as http_client
 
 
+from tagcube import __VERSION__
 from tagcube.utils.exceptions import TagCubeAPIException, IncorrectAPICredentials
 from tagcube.utils.resource import Resource
 from tagcube.utils.result_handlers import (ONE_RESULT, LATEST_RESULT,
@@ -38,13 +39,13 @@ You can't scan the specified domain. This happens in the following cases:
 
 class TagCubeClient(object):
 
-    ROOT_DOMAIN = os.environ.get('ROOT_DOMAIN', None) or 'api.tagcube.io'
-    ROOT_URL = 'https://%s/' % ROOT_DOMAIN
+    DEFAULT_ROOT_URL = 'https://api.tagcube.io/'
 
     API_VERSION = '1.0'
 
     SELF_URL = '/users/~'
     DOMAINS = '/domains/'
+    SCANS = '/scans/'
     VERIFICATIONS = '/verifications/'
     SCAN_PROFILES = '/profiles/'
 
@@ -55,6 +56,8 @@ class TagCubeClient(object):
         self.api_key = api_key
         self.session = None
 
+        self.root_url = os.environ.get('ROOT_URL', None) or self.DEFAULT_ROOT_URL
+
         self.set_verbose(verbose)
         self.configure_requests()
 
@@ -175,16 +178,16 @@ class TagCubeClient(object):
         This method's last step is to send a POST request to /1.0/scans/ using
         a post-data similar to:
 
-            {"verifications_href": "/1.0/verifications/6",
-             "profiles_href": "/1.0/profiles/2",
+            {"verification_href": "/1.0/verifications/6",
+             "profile_href": "/1.0/profiles/2",
              "start_time": "now",
              "email_notifications_href": [],
              "path_list": ["/"]}'
 
         :return: The newly generated scan id
         """
-        data = {"verifications_href": verification_resource.href,
-                "profiles_href": scan_profile_resource.href,
+        data = {"verification_href": verification_resource.href,
+                "profile_href": scan_profile_resource.href,
                 "start_time": "now",
                 "email_notifications_href": [n.href for n in notification_resource_list],
                 "path_list": path_list}
@@ -332,6 +335,15 @@ class TagCubeClient(object):
         url = self.build_full_url(self.DOMAINS)
         return self.create_resource(url, data)
 
+    def get_scan(self, scan_id):
+        """
+        :param scan_id: The scan ID as a string
+        :return: A resource containing the scan information
+        """
+        url = self.build_full_url('%s%s' % (self.SCANS, scan_id))
+        _, json_data = self.send_request(url)
+        return Resource(json_data)
+
     def create_resource(self, url, data):
         """
         Shortcut for creating a new resource
@@ -380,22 +392,47 @@ class TagCubeClient(object):
         self.session.auth = (self.email, self.api_key)
 
         headers = {'Content-Type': 'application/json',
-                   'User-Agent': 'TagCubeClient %s' % self.API_VERSION}
+                   'User-Agent': 'TagCubeClient %s' % __VERSION__}
         self.session.headers.update(headers)
 
-    def handle_api_errors(self, json_data):
+    def handle_api_errors(self, status_code, json_data):
         """
         This method parses all the HTTP responses sent by the REST API and
         raises exceptions if required. Basically tries to find responses with
         this format:
 
-            {u'error': [u'The domain foo.com already exists.']}
+            {
+                'error': ['The domain foo.com already exists.']
+            }
 
-        And raise TagCubeAPIException
+        Or this other:
+            {
+                "scans": {
+                    "__all__": [
+                        "Not a verified domain. You need to verify..."
+                    ]
+                }
+            }
+
+        And raise TagCubeAPIException with the correct message.
+
+        :param status_code: The HTTP response code
+        :param json_data: The HTTP response body decoded as JSON
         """
-        if 'error' in json_data and len(json_data) == 1 \
+        error_list = []
+
+        if status_code == 400:
+            for main_error_key in json_data:
+                for sub_error_key in json_data[main_error_key]:
+                    error_list.extend(json_data[main_error_key][sub_error_key])
+
+        elif 'error' in json_data and len(json_data) == 1 \
         and isinstance(json_data, dict) and isinstance(json_data['error'], list):
-            error_string = u' '.join(json_data['error'])
+            error_list = json_data['error']
+
+        # Only raise an exception if we had any errors
+        if error_list:
+            error_string = u' '.join(error_list)
             raise TagCubeAPIException(error_string)
 
     def send_request(self, url, json_data=None, method='GET'):
@@ -412,19 +449,24 @@ class TagCubeClient(object):
         if response.status_code == 401:
             raise IncorrectAPICredentials('Invalid TagCube API credentials')
 
-        json_data = response.json()
+        try:
+            json_data = response.json()
+        except ValueError:
+            msg = 'TagCube REST API did not return JSON, if this issue'\
+                  ' persists please contact support@tagcube.io'
+            raise TagCubeAPIException(msg)
 
         pretty_json = json.dumps(json_data, indent=4)
-        msg = 'Received HTTP response body from the wire:\n%s'
-        api_logger.debug(msg % pretty_json)
+        msg = 'Received %s HTTP response from the wire:\n%s'
+        api_logger.debug(msg % (response.status_code, pretty_json))
 
         # Error handling
-        self.handle_api_errors(json_data)
+        self.handle_api_errors(response.status_code, json_data)
 
         return response.status_code, json_data
 
     def build_full_url(self, last_part):
-        return '%s%s%s' % (self.ROOT_URL, self.API_VERSION, last_part)
+        return '%s%s%s' % (self.root_url, self.API_VERSION, last_part)
 
     def build_api_path(self, resource_name, last_part=''):
         return '/%s/%s/%s' % (self.API_VERSION, resource_name, last_part)
